use crate::spec::base::apple::{base, Arch, TargetAbi};
use crate::spec::{Cc, FramePointer, LinkerFlavor, Lld, SanitizerSet, Target, TargetOptions};

pub(crate) fn target() -> Target {
    let (mut opts, llvm_target, arch) = base("macos", Arch::X86_64, TargetAbi::Normal);
    opts.add_pre_link_args(LinkerFlavor::Darwin(Cc::Yes, Lld::No), &["-m64"]);
    Target {
        llvm_target,
        metadata: crate::spec::TargetMetadata {
            description: Some("64-bit macOS (10.12+, Sierra+)".into()),
            tier: Some(1),
            host_tools: Some(true),
            std: Some(true),
        },
        pointer_width: 64,
        data_layout:
            "e-m:o-p270:32:32-p271:32:32-p272:64:64-i64:64-i128:128-f80:128-n8:16:32:64-S128".into(),
        arch,
        options: TargetOptions {
            mcount: "\u{1}mcount".into(),
            max_atomic_width: Some(128), // penryn+ supports cmpxchg16b
            frame_pointer: FramePointer::Always,
            supported_sanitizers: SanitizerSet::ADDRESS
                | SanitizerSet::CFI
                | SanitizerSet::LEAK
                | SanitizerSet::THREAD,
            ..opts
        },
    }
}
